"use strict";(self["webpackChunk_jupyterlab_application_top"]=self["webpackChunk_jupyterlab_application_top"]||[]).push([[6053],{76053:(e,a,p)=>{p.d(a,{createTreemapServices:()=>t.d});var t=p(88451);var r=p(99246)}}]);