"use strict";(self["webpackChunk_jupyterlab_application_top"]=self["webpackChunk_jupyterlab_application_top"]||[]).push([[2305],{62305:(a,r,e)=>{e.d(r,{diagram:()=>l});var t=e(31288);var n=e(29479);var s=e(42418);var i=e(70416);var p=e(24010);var o={parse:(0,i.K2)((async a=>{const r=await(0,p.qg)("info",a);i.Rm.debug(r)}),"parse")};var v={version:t.n.version+(true?"":0)};var d=(0,i.K2)((()=>v.version),"getVersion");var c={getVersion:d};var u=(0,i.K2)(((a,r,e)=>{i.Rm.debug("rendering info diagram\n"+a);const t=(0,n.D)(r);(0,s.a$)(t,100,400,true);const p=t.append("g");p.append("text").attr("x",100).attr("y",40).attr("class","version").attr("font-size",32).style("text-anchor","middle").text(`v${e}`)}),"draw");var g={draw:u};var l={parser:o,db:c,renderer:g}}}]);
//# sourceMappingURL=2305.ea434ad0221e3d41564e.js.map?v=ea434ad0221e3d41564e